function[sep,pred,bs,bcoeffs,tscores,ploads,dof]=caltestxx(calx,caly,testx,testy,func,cent,varargin)
 
  // function[sep,pred,bs]=caltestxx(calx,caly,testx,testy,'func',(r),centering,nf,autress varargin)
  //
  // This function (1) calculates a regression model with nv latent variables 
  //                   using the 'func' method
  //                   calibrated on calx and caly; 
  //               (2) applies this model to testx and testy;
  //
  // Input:
  // ======
  // calx:        matrix n x p for calibration
  // caly:        vector p X 1 of reference values associated to calx
  // testx:       matrix nv x p for validation
  // testy:       vector nv x 1 of reference values for testx
  // 'func':      function called for each step of the cross validation 
  //              possible choices: 'pls' , 'pcr', 'vodka' ,'ridge' 
  // cent:        if 1, data are centered 
  //              if 0, data are not centered 
  //
  // Output:
  // =======
  // sep:        vector, standard error of prediction 
  // pred:       matrix nv X nf of the predicted values for testx and the nf models
  //
  // Miscellaneous:
  // ==============
  // JC Boulet (INRA) & JM Roger (IRSTEA), France
  // Last update: 2012, March, 30
  // ---------------------------------------------

  // size of the data
  [n,p]=size(calx);
  
  xm=mean(calx,1);
  ym=mean(caly,1);
  calx=calx- ones(size(calx,1),1)*xm*cent;
  testx=testx-ones(size(testx,1),1)*xm*cent;
  caly=caly-ones(size(calx,1),1)*ym*cent;

  // model calculation
  functionname='cal'+func;
  execstr(msprintf('[bcoeffs,tscores,ploads,dof]= %s(calx,caly,varargin(:));',functionname));
  
  // model application
  pred = testx*bcoeffs + ones(size(testx,1),size(bcoeffs,2))*ym*cent; //JCB 19fev13

  nf = size(pred,2);  

  for j = 1:nf
     press(j) = sum(sum((pred(:,j)-testy).^2));
  end
  
  sep = sqrt(press / size(testy,1));
  bs = mean( pred - testy*ones(1,nf),'r')';

endfunction





